/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */


package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TMCInteger;

/**
 * TIC3-Status.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3Status.java 63650 2016-09-22 17:11:32Z gieseler $     
 */

public class TIC3Status extends TMCInteger {

	/**
	 * Enumerator TIC3-Status.
	 */
	public enum TIC3StatusEnum {
		
		/** unbekannter Status. */
		Unbekannt("Unbekannt", 0),

		/** Neu. */
		Neu("Neu", 1),

		/** Ge&auml;ndert. */
		Geaendert("Geändert", 2),

		/** Gel&ouml;scht. */
		Geloescht("Gelöscht", 3);
		
		/**
		 * Gibt eine passende Status-Instanz zur&uuml;ck.
		 *
		 * @param id
		 *            numerischer Wert
		 * @return zum numerischen Wert passende Instanz
		 * @throws TIC3Exception
		 *             bei ung&uuml;ltigem Wert
		 */
		public static TIC3StatusEnum getInstance(final int id) throws TIC3Exception {
			switch (id) {
			case 0:
				return Unbekannt;
			case 1:
				return Neu;
			case 2:
				return Geaendert;
			case 3:
				return Geloescht;
			default:
				throw new TIC3Exception("Kein TIC3-Status mit id=" + id + " definiert.");
			}
		}

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TIC3StatusEnum(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert des Status
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert des Status
		 */
		public String getValue() {
			return value;
		}
	}

	/**
	 * Status.
	 */
	private TIC3StatusEnum status = TIC3StatusEnum.Unbekannt;
	

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3Status(final String xmlName, final String davName) {
		super(xmlName, davName);
	}

	@Override
	public void getDavDaten(final Data davdata) throws TIC3Exception {
		super.getDavDaten(davdata);
		status = TIC3StatusEnum.getInstance(getWert());
	}

	/**
	 * Gibt den Status der Meldung zur&uuml;ck.
	 *
	 * @return {@link TIC3StatusEnum}
	 */
	public TIC3StatusEnum getTIC3MeldungsStatus() {
		return status;
	}

	@Override
	public void getXmlDaten(final Node node) throws TIC3Exception {
		status = TIC3StatusEnum.getInstance(Integer.parseInt(node.getTextContent()));
	}

	@Override
	public void setDavDaten(final Data davdata) throws TIC3Exception {
		davdata.getUnscaledValue(getDavAttributName()).set(status.getId());
	}

	/**
	 * Setzt den Status der Meldung.
	 *
	 * @param neuerstatus
	 *            neuer Status
	 */
	public void setTIC3MeldungsStatus(final TIC3StatusEnum neuerstatus) {
		status = neuerstatus;
		setWert(status.id);
	}
}
