/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.LMSParameter;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3InfoAttribut;

/**
 * TIC3-codierte Ereignisse.
 * <p>
 * Entspricht TIC3-Typ 'TrafficAndTravelEventCodeAndAttributeType'.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3TICEvent.java 63650 2016-09-22 17:11:32Z gieseler $
 */
public class TIC3TICEvent extends AbstractTIC3InfoElement {

	/**
	 * TIC3 Info XML Element: Tic3Event (T3E), A list of one or more TIC3
	 * traffic and travel event codes and their attributes, where the TIC3 event
	 * codes are defined based on a combination of standards such asTMC or SAE
	 * RDS.
	 */
	public static final String XML_ELEMENT_TICEVENT = "Tic3Event";

	/**
	 * DAV-Attribut.
	 */
	public static final String DAV_ATTR_TICEVENT = "TIC3Tic3Event";

	/**
	 * Beschreibung.
	 * <p>
	 * Beschreibung aus Wert des 'description'-Attributes.
	 * </p>
	 */
	private TIC3InfoAttribut beschreibung = new TIC3InfoAttribut("description", "Beschreibung");

	/**
	 * Event-Code.
	 * <p>
	 * TIC3 Info XML Element: TrafficAndTravelEventCode (TEC), A reference to
	 * "Traffic and Travel Event Code".
	 * </p>
	 */
	private final TIC3Text trafficAndTravelEventCode = new TIC3Text("TrafficAndTravelEventCode",
			"VerkehrsUndReiseereigniscode", "value");

	/**
	 * Event-Attribute.
	 * <p>
	 * TIC3 Info XML Element: TrafficAndTravelEventAttribute (TEA), A list of
	 * traffic and travel event attributes corresponding to the traffic and
	 * travel event code.
	 * </p>
	 */
	private final List<TIC3TICEventVerkehrsUndReiseereignisAttribut> eventAttribute = new ArrayList<>();

	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3TICEvent() {
		super(XML_ELEMENT_TICEVENT, null);
		addAttribut(beschreibung);
		addKindElement(trafficAndTravelEventCode);
	}

	@Override
	public void publizieren(final Data davdata, final LMSParameter parameter) throws TIC3Exception {
		super.publizieren(davdata, parameter);

		final Data ddata = getLocalDavData(davdata);

		if (eventAttribute.size() > 0) {
			final Data.Array array = ddata
					.getArray(TIC3TICEventVerkehrsUndReiseereignisAttribut.DAV_ATTR_TICEVENT_ATTRIBUTE);
			array.setLength(eventAttribute.size());
			for (int i = 0; i < eventAttribute.size(); i++) {
				eventAttribute.get(i).publizieren(array.getItem(i), parameter);
			}
		}
	}

	@Override
	public void einlesenXML(final Node node) throws TIC3Exception {
		super.einlesenXML(node);
		final NodeList nl = node.getChildNodes();

		for (int i = 0; i < nl.getLength(); i++) {
			final Node n = nl.item(i);
			if (n.getNodeName().equals(TIC3TICEventVerkehrsUndReiseereignisAttribut.XML_ELEMENT_TICEVENT_ATTRIBUTE)) {
				final TIC3TICEventVerkehrsUndReiseereignisAttribut att = new TIC3TICEventVerkehrsUndReiseereignisAttribut();
				att.einlesenXML(n);
				eventAttribute.add(att);
			}
		}
	}

	@Override
	public String toString() {
		return this.getClass().getSimpleName();
	}
}
