/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */


package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;

/**
 * TIC3-Zeitzone.
 * 
 * TIC3 Info XML Element: TimeZone (TZO), The time zone as defined for Microsoft operating systems, described by a name and offset to Coordinated Universal Time (UTC), and used for time data which is provided in the local time and which has been adjusted to local Daylight Savings Time (DST).
 * 
 * <br>
 * <p>Bsp:	&lt;TimeZone name="Zeitzone" value="(UTC+01:00) Amsterdam, Berlin, Bern, Rom, Stockholm, Wien"&gt;4&lt;/TimeZone&gt;</p>
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3ZeitZone.java 63650 2016-09-22 17:11:32Z gieseler $     
 */

public class TIC3ZeitZone extends TIC3Text {
	
	/**
	 * Enumerator TIC3-Zeitzone.
	 */
	public enum TIC3ZeitZoneEnum {
		
		/** Unbekannt. */
		Unbekannt("Unbekannt", -1),
		
		/** (UTC+01:00) Amsterdam, Berlin, Bern, Rom, Stockholm, Wien". */
		CET("CET", 4);

		/**
		 * Gibt eine passende Zeitzone-Instanz zur&uuml;ck.
		 *
		 * @param id
		 *            numerischer Wert
		 * @return zum numerischen Wert passende Instanz
		 * @throws TIC3Exception
		 *             bei ung&uuml;ltigem Wert
		 */
		public static TIC3ZeitZoneEnum getInstance(final int id) throws TIC3Exception {
			switch (id) {
			case 4:
				return CET;
			default:
				throw new TIC3Exception("Kein TIC3-Zeitzone mit id=" + id + " definiert.");
			}
		}

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TIC3ZeitZoneEnum(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert der Zeitzone
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert der Zeitzone
		 */
		public String getValue() {
			return value;
		}
	}

	/**
	 * Zeitzone.
	 */
	private TIC3ZeitZoneEnum zeitzone = TIC3ZeitZoneEnum.Unbekannt;
	

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3ZeitZone(final String xmlName, final String davName) {
		super(xmlName, davName, "value");
	}


	/**
	 * Gibt die Zeitzone zur&uuml;ck.
	 * 
	 * @return {@link TIC3ZeitZoneEnum}
	 */
	public TIC3ZeitZoneEnum getZeitzone() {
		return zeitzone;
	}
}
